@@ -1,15 +1,15 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::Builder;
-use glib::object::{Cast, IsA};
-use glib::translate::*;
-use glib::Object;
 use std::path::Path;
 
+use glib::{translate::*, IntoGStr, Object};
+
+use crate::{prelude::*, Builder};
+
 impl Builder {
     #[doc(alias = "gtk_builder_new_from_file")]
     #[doc(alias = "new_from_file")]
-    pub fn from_file<T: AsRef<Path>>(file_path: T) -> Self {
+    pub fn from_file(file_path: impl AsRef<Path>) -> Self {
         assert_initialized_main_thread!();
         unsafe {
             from_glib_full(ffi::gtk_builder_new_from_file(
@@ -18,44 +18,37 @@ impl Builder {
         }
     }
 
-    #[doc(alias = "gtk_builder_get_object")]
-    #[doc(alias = "get_object")]
-    pub fn object<T: IsA<Object>>(&self, name: &str) -> Option<T> {
+    #[doc(alias = "gtk_builder_get_current_object")]
+    #[doc(alias = "get_current_object")]
+    pub fn current_object(&self) -> Option<Object> {
         unsafe {
-            Option::<Object>::from_glib_none(ffi::gtk_builder_get_object(
-                self.to_glib_none().0,
-                name.to_glib_none().0,
-            ))
-            .and_then(|obj| obj.dynamic_cast::<T>().ok())
-        }
-    }
-
-    #[doc(alias = "gtk_builder_value_from_string")]
-    pub fn value_from_string(
-        &self,
-        pspec: &glib::ParamSpec,
-        string: &str,
-    ) -> Result<glib::Value, glib::Error> {
-        unsafe {
-            let mut value = glib::Value::uninitialized();
-            let mut error = std::ptr::null_mut();
-            let _ = ffi::gtk_builder_value_from_string(
-                self.to_glib_none().0,
-                pspec.to_glib_none().0,
-                string.to_glib_none().0,
-                value.to_glib_none_mut().0,
-                &mut error,
-            );
-            if error.is_null() {
-                Ok(value)
+            let ptr = ffi::gtk_builder_get_current_object(self.to_glib_none().0);
+            if ptr.is_null() {
+                None
             } else {
-                Err(from_glib_full(error))
+                glib::gobject_ffi::g_object_ref(ptr);
+                Some(from_glib_full(ptr))
             }
         }
     }
 
+    #[doc(alias = "gtk_builder_get_object")]
+    #[doc(alias = "get_object")]
+    pub fn object<T: IsA<Object>>(&self, name: impl IntoGStr) -> Option<T> {
+        unsafe {
+            T::ensure_type();
+            name.run_with_gstr(|name| {
+                Option::<Object>::from_glib_none(ffi::gtk_builder_get_object(
+                    self.to_glib_none().0,
+                    name.as_ptr(),
+                ))
+                .and_then(|obj| obj.dynamic_cast::<T>().ok())
+            })
+        }
+    }
+
     #[doc(alias = "gtk_builder_add_from_file")]
-    pub fn add_from_file<T: AsRef<Path>>(&self, file_path: T) -> Result<(), glib::Error> {
+    pub fn add_from_file(&self, file_path: impl AsRef<Path>) -> Result<(), glib::Error> {
         unsafe {
             let mut error = ::std::ptr::null_mut();
             ffi::gtk_builder_add_from_file(
