@@ -1,15 +1,16 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::prelude::*;
-use crate::{TreeIter, TreePath, TreeRowReference};
 use glib::translate::*;
-use glib::IsA;
+
+use crate::{prelude::*, TreeIter, TreePath, TreeRowReference};
 
 impl TreeRowReference {
     #[doc(alias = "gtk_tree_row_reference_reordered")]
-    pub fn reordered<P: IsA<glib::Object>>(
+    #[cfg_attr(feature = "v4_10", deprecated = "Since 4.10")]
+    #[allow(deprecated)]
+    pub fn reordered(
         &self,
-        proxy: &P,
+        proxy: &impl IsA<glib::Object>,
         path: &TreePath,
         iter: &TreeIter,
         new_order: &[i32],
@@ -17,7 +18,7 @@ impl TreeRowReference {
         assert_eq!(
             new_order.len() as i32,
             self.model().iter_n_children(Some(iter)),
-            "TreeRowReference got passed a `new_order` bigger than the total childrens in the model for the passed iter"
+            "TreeRowReference got passed a `new_order` bigger than the total children in the model for the passed iter"
         );
         assert_initialized_main_thread!();
         unsafe {
